==> ReleaseV1.1.1.zip: winginterfacelibrary/src/LiveConsultation/CancelInvitingInLiveConsultationRequest.cs <==
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Enum.NotificationEnum;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 取消会诊过程邀请中的成员请求
    /// </summary>
    public class CancelInvitingInLiveConsultationRequest : TokenRequest
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 用户或者设备编码集合
        /// </summary>
        /// <value></value>
        public IList<string> InviteCodes { get; set; }

        /// <summary>
        ///房间号码
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }
    }

    /// <summary>
    /// 取消会诊过程中的邀请的成员请求结果
    /// </summary>
    public class CancelInvitingInLiveConsultationResult
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
    }

    /// <summary>
    /// 取消会诊过程中邀请成员的通知
    /// </summary>
    public class CancelInvitingInLiveConsultationNotification
    {

        /// <summary>
        /// 通知类型枚举 取消会诊过程中邀请成员的通知
        /// </summary>
        /// <value>1</value>
        public NotificationTypeEnum NotificationType => NotificationTypeEnum.CancelInvitingInLiveConsultationNotification;
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
    }
}

==> ReleaseV1.1.2.zip: winginterfacelibrary/src/LiveConsultation/CancelInvitingInLiveConsultationRequest.cs <==
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Notifications;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 取消会诊过程邀请中的成员请求
    /// </summary>
    public class CancelInvitingInLiveConsultationRequest : TokenRequest
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 用户或者设备编码集合
        /// </summary>
        /// <value></value>
        public IList<string> InviteCodes { get; set; }
    }

    /// <summary>
    /// 取消会诊过程中的邀请的成员请求结果
    /// </summary>
    public class CancelInvitingInLiveConsultationResult
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
    }

    /// <summary>
    /// 取消会诊过程中邀请成员的通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class CancelInvitingInLiveConsultationNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 取消会诊过程中邀请成员的通知
        /// </summary>
        /// <value>7</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.CancelInvitingInLiveConsultationNotification;
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
    }
}
